@@ -67,6 +67,16 @@ def validate_project(input_file_or_json: Union[dict[str, Any], str]) -> bool:
     try:
         jsonschema.validate(instance=project_definition, schema=project_schema)
     except jsonschema.ValidationError as err:
+        # Check for the specific case of private permissions with overrule
+        if (
+            "should not be valid under {'required': ['default_permissions_overrule']}" in err.message
+            and project_definition.get("project", {}).get("default_permissions") == "private"
+        ):
+            raise BaseError(
+                "When default_permissions is 'private', default_permissions_overrule cannot be specified. "
+                "Private permissions cannot be overruled."
+            ) from None
+
         raise BaseError(
             f"The JSON project file cannot be created due to the following validation error: {err.message}.\n"
             f"The error occurred at {err.json_path}:\n{err.instance}"
