@@ -8,7 +8,7 @@ from typing import Any
 
 from dsp_tools.error.xmllib_warnings import MessageInfo
 from dsp_tools.error.xmllib_warnings_util import emit_xmllib_input_type_mismatch_warning
-from dsp_tools.error.xmllib_warnings_util import raise_input_error
+from dsp_tools.error.xmllib_warnings_util import raise_xmllib_input_error
 from dsp_tools.xmllib.internal.input_converters import check_and_fix_collection_input
 from dsp_tools.xmllib.internal.input_converters import check_and_fix_is_non_empty_string
 from dsp_tools.xmllib.models.config_options import NewlineReplacement
@@ -1558,7 +1558,7 @@ class Resource:
             comment: optional comment
 
         Raises:
-            InputError: If the resource already has a file or IIIF URI value
+            XmllibInputError: If the resource already has a file or IIIF URI value
 
         Returns:
             The original resource, with the added value
@@ -1591,7 +1591,7 @@ class Resource:
                 resource_id=self.res_id,
                 field="file / iiif-uri",
             )
-            raise_input_error(msg_info)
+            raise_xmllib_input_error(msg_info)
         meta = Metadata.new(
             license=license,
             copyright_holder=copyright_holder,
@@ -1626,7 +1626,7 @@ class Resource:
             comment: optional comment
 
         Raises:
-            InputError: If the resource already has a file or IIIF URI value
+            XmllibInputError: If the resource already has a file or IIIF URI value
 
         Returns:
             The original resource, with the added value
@@ -1648,7 +1648,7 @@ class Resource:
                 resource_id=self.res_id,
                 field="file / iiif-uri",
             )
-            raise_input_error(msg_info)
+            raise_xmllib_input_error(msg_info)
         meta = Metadata.new(
             license=license,
             copyright_holder=copyright_holder,
@@ -1677,7 +1677,7 @@ class Resource:
             ark: Original ARK in SALSAH
 
         Raises:
-            InputError: if metadata already exists
+            XmllibInputError: if metadata already exists
 
         Returns:
             The original resource, with the added migration metadata
@@ -1701,6 +1701,6 @@ class Resource:
             msg_info = MessageInfo(
                 "This resource already contains migration metadata, no new data can be added.", resource_id=self.res_id
             )
-            raise_input_error(msg_info)
+            raise_xmllib_input_error(msg_info)
         self.migration_metadata = MigrationMetadata(creation_date=creation_date, iri=iri, ark=ark, res_id=self.res_id)
         return self
