@@ -2,18 +2,22 @@
 
 import pytest
 
-from dsp_tools.commands.validate_data.get_rdf_like_data import _get_file_metadata
-from dsp_tools.commands.validate_data.get_rdf_like_data import _get_file_value
-from dsp_tools.commands.validate_data.get_rdf_like_data import _get_list_value_str
-from dsp_tools.commands.validate_data.get_rdf_like_data import _get_one_resource
-from dsp_tools.commands.validate_data.get_rdf_like_data import _get_one_value
-from dsp_tools.commands.validate_data.get_rdf_like_data import get_rdf_like_data
 from dsp_tools.commands.validate_data.models.api_responses import ListLookup
 from dsp_tools.commands.validate_data.models.rdf_like_data import PropertyObject
 from dsp_tools.commands.validate_data.models.rdf_like_data import RdfLikeResource
 from dsp_tools.commands.validate_data.models.rdf_like_data import RdfLikeValue
 from dsp_tools.commands.validate_data.models.rdf_like_data import TripleObjectType
 from dsp_tools.commands.validate_data.models.rdf_like_data import TriplePropertyType
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_date_str_and_precision
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_file_metadata
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_file_value
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_list_value_str
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_one_resource
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_one_value
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import _get_xsd_like_dates
+from dsp_tools.commands.validate_data.prepare_data.get_rdf_like_data import get_rdf_like_data
+from dsp_tools.utils.data_formats.date_util import Era
+from dsp_tools.utils.data_formats.date_util import SingleDate
 from dsp_tools.utils.rdflib_constants import KNORA_API_STR
 from dsp_tools.utils.xml_parsing.models.parsed_resource import KnoraValueType
 from dsp_tools.utils.xml_parsing.models.parsed_resource import ParsedFileValue
@@ -68,7 +72,6 @@ class TestResource:
         result = _get_one_resource(res, {}, LIST_LOOKUP)
         assert result.res_id == "one"
         assert len(result.property_objects) == 2
-        assert not result.asset_value
         lbl, rdf_type, _ = _get_label_and_type(result)
         assert lbl.object_value == "lbl"
         assert lbl.object_type == TripleObjectType.STRING
@@ -89,7 +92,6 @@ class TestResource:
         result = _get_one_resource(res, {}, LIST_LOOKUP)
         assert result.res_id == "one"
         assert len(result.property_objects) == 3
-        assert not result.asset_value
         lbl, rdf_type, perm = _get_label_and_type(result)
         assert len(perm) == 1
         permission = perm.pop(0)
@@ -117,7 +119,6 @@ class TestResource:
         result = result_list.resources.pop(0)
         assert result.res_id == "one"
         assert len(result.property_objects) == 2
-        assert not result.asset_value
         lbl, rdf_type, _ = _get_label_and_type(result)
         assert lbl.object_value == "lbl"
         assert lbl.object_type == TripleObjectType.STRING
@@ -157,7 +158,6 @@ class TestResource:
         result = _get_one_resource(res, {}, LIST_LOOKUP)
         assert result.res_id == "one"
         assert len(result.property_objects) == 3
-        assert not result.asset_value
         lbl, rdf_type, _ = _get_label_and_type(result)
         assert lbl.object_value == "lbl"
         assert lbl.object_type == TripleObjectType.STRING
@@ -230,13 +230,78 @@ class TestValues:
         assert res.knora_type == KnoraValueType.COLOR_VALUE
         assert not res.value_metadata
 
-    def test_date_corr(self):
+    def test_date_corr_with_date_range_yyyy(self):
         val = ParsedValue(HAS_PROP, "CE:1849:CE:1850", KnoraValueType.DATE_VALUE, None, None)
         res = _get_one_value(val, LIST_LOOKUP)
         assert res.user_facing_prop == HAS_PROP
         assert res.user_facing_value == "CE:1849:CE:1850"
         assert res.knora_type == KnoraValueType.DATE_VALUE
-        assert not res.value_metadata
+        assert len(res.value_metadata) == 2
+        start = next(x for x in res.value_metadata if x.property_type == TriplePropertyType.KNORA_DATE_START)
+        assert start.object_value == "1849"
+        assert start.object_type == TripleObjectType.DATE_YYYY
+        end = next(x for x in res.value_metadata if x.property_type == TriplePropertyType.KNORA_DATE_END)
+        assert end.object_value == "1850"
+        assert end.object_type == TripleObjectType.DATE_YYYY
+
+    def test_get_xsd_like_dates_only_start(self):
+        date_str = "GREGORIAN:CE:1800-01-01"
+        result = _get_xsd_like_dates(date_str)
+        assert len(result) == 2
+        start, end = result
+        assert start.property_type == TriplePropertyType.KNORA_DATE_START
+        assert start.object_value == "1800-01-01"
+        assert start.object_type == TripleObjectType.DATE_YYYY_MM_DD
+        assert end.property_type == TriplePropertyType.KNORA_DATE_END
+        assert end.object_value == "1800-01-01"
+        assert end.object_type == TripleObjectType.DATE_YYYY_MM_DD
+
+    def test_get_xsd_like_dates_mixed_precision(self):
+        date_str = "GREGORIAN:CE:1800-01-01:CE:1900"
+        result = _get_xsd_like_dates(date_str)
+        assert len(result) == 2
+        start, end = result
+        assert start.property_type == TriplePropertyType.KNORA_DATE_START
+        assert start.object_value == "1800-01-01"
+        assert start.object_type == TripleObjectType.DATE_YYYY_MM_DD
+        assert end.property_type == TriplePropertyType.KNORA_DATE_END
+        assert end.object_value == "1900"
+        assert end.object_type == TripleObjectType.DATE_YYYY
+
+    def test_get_xsd_like_dates_second_era_wrong(self):
+        date_str = "GREGORIAN:CE:2000:BCE:1900"
+        result = _get_xsd_like_dates(date_str)
+        assert len(result) == 1
+        start = result.pop(0)
+        assert start.property_type == TriplePropertyType.KNORA_DATE_START
+        assert start.object_value == "2000"
+        assert start.object_type == TripleObjectType.DATE_YYYY
+
+    @pytest.mark.parametrize(
+        "date",
+        [
+            "BCE:2020-01-01:BCE:2021-02-02",  # BCE is not supported
+            "BC:2020-01-01:BC:2021-02-02",  # BC is not supported
+        ],
+    )
+    def test_dates_not_supported(self, date):
+        result = _get_xsd_like_dates(date)
+        assert not result
+
+    @pytest.mark.parametrize(
+        ("date", "expected_str", "expected_type"),
+        [
+            (SingleDate(era=None, year=1900, month=10, day=1), "1900-10-01", TripleObjectType.DATE_YYYY_MM_DD),
+            (SingleDate(era=None, year=1900, month=10, day=None), "1900-10", TripleObjectType.DATE_YYYY_MM),
+            (SingleDate(era=None, year=900, month=None, day=None), "0900", TripleObjectType.DATE_YYYY),
+            (SingleDate(era=Era.CE, year=900, month=None, day=None), "0900", TripleObjectType.DATE_YYYY),
+            (SingleDate(era=Era.AD, year=900, month=None, day=None), "0900", TripleObjectType.DATE_YYYY),
+        ],
+    )
+    def test_get_date_str_and_precision(self, date, expected_str, expected_type):
+        result_str, result_type = _get_date_str_and_precision(date)
+        assert result_str == expected_str
+        assert result_type == expected_type
 
     def test_decimal_corr(self):
         val = ParsedValue(HAS_PROP, "1.4", KnoraValueType.DECIMAL_VALUE, None, None)
